@@ -525,18 +525,18 @@ class LaharFlowData(object):
         self.txt_files.sort()
     
     def _snapshot_txt_files(self):
-        txt_files = [f.strip('.txt') for f in self.txt_files if f.strip('.txt').isnumeric()]
+        txt_files = [f for f in self.txt_files if f.strip('.txt').isnumeric()]
         txt_files.sort()
         return txt_files
     
     def _snapshot_nc_files(self):
-        nc_files = [f.strip('.nc') for f in self.nc_files if f.strip('.nc').isnumeric()]
+        nc_files = [f for f in self.nc_files if f.strip('.nc').isnumeric()]
         nc_files.sort()
         return nc_files
 
     def get_snapshot_files(self):
-        txt_files = self._snapshot_txt_files()
-        nc_files = self._snapshot_nc_files()
+        txt_files = [f.strip('.txt') for f in self.txt_files if f.strip('.txt').isnumeric()]
+        nc_files = [f.strip('.nc') for f in self.nc_files if f.strip('.nc').isnumeric()]
         sfiles = list(set(txt_files + nc_files))
         sfiles.sort()
         return sfiles
@@ -1019,8 +1019,9 @@ class LaharFlowData(object):
             self.MaxConc = None
         
         last_outfile = self._snapshot_nc_files()[-1]
+        LaharFlowFile = self._extract_file(last_outfile)
         try:
-            maxE, maxD = nc_min_max(last_outfile, var='elevation_change')
+            maxE, maxD = nc_min_max(LaharFlowFile, var='elevation_change')
             self.MaxDeposit = maxD['elevation_change']
             self.MaxErosion = -maxE['elevation_change']
         except:
